@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/AdminGenericInterfaceInvokerDefault.pm - provides a log view for admins
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,10 +11,9 @@ package Kernel::Modules::AdminGenericInterfaceInvokerDefault;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.9 $) [1];
-
 use Kernel::System::GenericInterface::Webservice;
+use Kernel::System::DynamicField;
+use Kernel::System::Event;
 
 use Kernel::System::VariableCheck qw(:all);
 
@@ -31,7 +29,12 @@ sub new {
         }
     }
 
-    $Self->{WebserviceObject} = Kernel::System::GenericInterface::Webservice->new( %{$Self} );
+    $Self->{WebserviceObject}   = Kernel::System::GenericInterface::Webservice->new( %{$Self} );
+    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new( %{$Self} );
+    $Self->{EventObject}        = Kernel::System::Event->new(
+        %{$Self},
+        DynamicFieldObject => $Self->{DynamicFieldObject},
+    );
 
     return $Self;
 }
@@ -210,13 +213,12 @@ sub _AddAction {
     }
 
     my $Config = {
-        Type => $GetParam{InvokerType},
+        Type        => $GetParam{InvokerType},
         Description => $Self->{ParamObject}->GetParam( Param => 'Description' ) || '',
     };
 
     my $MappingInbound = $Self->{ParamObject}->GetParam( Param => 'MappingInbound' );
-    $MappingInbound
-        = $Self->_MappingTypeCheck( MappingType => $MappingInbound ) ? $MappingInbound : '';
+    $MappingInbound = $Self->_MappingTypeCheck( MappingType => $MappingInbound ) ? $MappingInbound : '';
 
     if ($MappingInbound) {
         $Config->{MappingInbound} = {
@@ -225,8 +227,7 @@ sub _AddAction {
     }
 
     my $MappingOutbound = $Self->{ParamObject}->GetParam( Param => 'MappingOutbound' );
-    $MappingOutbound
-        = $Self->_MappingTypeCheck( MappingType => $MappingOutbound ) ? $MappingOutbound : '';
+    $MappingOutbound = $Self->_MappingTypeCheck( MappingType => $MappingOutbound ) ? $MappingOutbound : '';
 
     if ($MappingOutbound) {
         $Config->{MappingOutbound} = {
@@ -244,8 +245,7 @@ sub _AddAction {
         );
     }
 
-    my $RedirectURL
-        = "Action=AdminGenericInterfaceInvokerDefault;Subaction=Change;WebserviceID=$WebserviceID;";
+    my $RedirectURL = "Action=AdminGenericInterfaceInvokerDefault;Subaction=Change;WebserviceID=$WebserviceID;";
     $RedirectURL
         .= 'Invoker=' . $Self->{LayoutObject}->LinkEncode( $GetParam{Invoker} ) . ';';
 
@@ -329,8 +329,7 @@ sub _ChangeAction {
         );
     }
 
-    my $InvokerConfig
-        = $WebserviceData->{Config}->{Requester}->{Invoker}->{ $GetParam{OldInvoker} };
+    my $InvokerConfig = $WebserviceData->{Config}->{Requester}->{Invoker}->{ $GetParam{OldInvoker} };
 
     # Invoker was renamed, avoid conflicts
     if ( $GetParam{OldInvoker} ne $GetParam{Invoker} ) {
@@ -365,8 +364,7 @@ sub _ChangeAction {
 
     # Now handle mappings. If mapping types were not changed, keep the mapping configuration.
     my $MappingInbound = $Self->{ParamObject}->GetParam( Param => 'MappingInbound' );
-    $MappingInbound
-        = $Self->_MappingTypeCheck( MappingType => $MappingInbound ) ? $MappingInbound : '';
+    $MappingInbound = $Self->_MappingTypeCheck( MappingType => $MappingInbound ) ? $MappingInbound : '';
 
     # No inbound mapping set, make sure it is not present in the configuration.
     if ( !$MappingInbound ) {
@@ -382,8 +380,7 @@ sub _ChangeAction {
     }
 
     my $MappingOutbound = $Self->{ParamObject}->GetParam( Param => 'MappingOutbound' );
-    $MappingOutbound
-        = $Self->_MappingTypeCheck( MappingType => $MappingOutbound ) ? $MappingOutbound : '';
+    $MappingOutbound = $Self->_MappingTypeCheck( MappingType => $MappingOutbound ) ? $MappingOutbound : '';
 
     # No outbound mapping set, make sure it is not present in the configuration.
     if ( !$MappingOutbound ) {
@@ -414,14 +411,12 @@ sub _ChangeAction {
     my $SelectedEventType = $Self->{ParamObject}->GetParam( Param => 'EventType' );
 
     # Save button: stay in edit mode.
-    my $RedirectURL
-        = "Action=AdminGenericInterfaceInvokerDefault;Subaction=Change;WebserviceID=$WebserviceID;"
+    my $RedirectURL = "Action=AdminGenericInterfaceInvokerDefault;Subaction=Change;WebserviceID=$WebserviceID;"
         . "Invoker=$GetParam{Invoker};EventType=$SelectedEventType";
 
     # Save and finish button: go to Webservice.
     if ( $Self->{ParamObject}->GetParam( Param => 'ReturnToWebservice' ) ) {
-        $RedirectURL
-            = "Action=AdminGenericInterfaceWebservice;Subaction=Change;WebserviceID=$WebserviceID;";
+        $RedirectURL = "Action=AdminGenericInterfaceWebservice;Subaction=Change;WebserviceID=$WebserviceID;";
 
     }
 
@@ -514,8 +509,7 @@ sub _ShowScreen {
     # Inbound mapping
     my @MappingList = sort keys %{$Mappings};
 
-    my $MappingInbound
-        = $Self->_MappingTypeCheck( MappingType => $Param{MappingInbound} )
+    my $MappingInbound = $Self->_MappingTypeCheck( MappingType => $Param{MappingInbound} )
         ? $Param{MappingInbound}
         : '';
 
@@ -543,8 +537,7 @@ sub _ShowScreen {
     }
 
     # Outbound mapping
-    my $MappingOutbound
-        = $Self->_MappingTypeCheck( MappingType => $Param{MappingOutbound} )
+    my $MappingOutbound = $Self->_MappingTypeCheck( MappingType => $Param{MappingOutbound} )
         ? $Param{MappingOutbound}
         : '';
 
@@ -581,8 +574,7 @@ sub _ShowScreen {
         );
     }
 
-    # get registered event triggers from the config
-    my $RegisteredEvents = $Self->{ConfigObject}->Get('GenericInterface::Invoker::Event');
+    my %RegisteredEvents = $Self->{EventObject}->EventList();
 
     my %InvokerEventLookup;
 
@@ -603,8 +595,8 @@ sub _ShowScreen {
         # but left if is needed in future
         my $EventType;
         EVENTTYPE:
-        for my $Type ( sort keys %{$RegisteredEvents} ) {
-            if ( $RegisteredEvents->{$Type}->{ $Event->{Event} } ) {
+        for my $Type ( sort keys %RegisteredEvents ) {
+            if ( grep { $_ eq $Event->{Event} } @{ $RegisteredEvents{$Type} || [] } ) {
                 $EventType = $Type;
                 last EVENTTYPE;
             }
@@ -627,16 +619,14 @@ sub _ShowScreen {
 
     # create event trigger selectors (one for each type)
     TYPE:
-    for my $Type ( sort keys %{$RegisteredEvents} ) {
-        next TYPE if !$Type;
+    for my $Type ( sort keys %RegisteredEvents ) {
 
         # refresh event list for each event type
         my @EventList;
 
         EVENT:
-        for my $Event ( sort keys %{ $RegisteredEvents->{$Type} } ) {
-            next EVENT if !$RegisteredEvents->{$Type}->{$Event};
-            next EVENT if $InvokerEventLookup{$Event};
+        for my $Event ( @{ $RegisteredEvents{$Type} || [] } ) {
+            next EVENT if $InvokerEventLookup{$Event};    # only add events that are not used yet
             push @EventList, $Event;
         }
 
@@ -652,6 +642,7 @@ sub _ShowScreen {
             Name         => $Type . 'Event',
             Sort         => 'AlphanumericValue',
             PossibleNone => 0,
+            Title        => $Self->{LayoutObject}->{LanguageObject}->Translate('Event'),
             Class        => 'EventList GenericInterfaceSpacing ' . $EventListHidden,
         );
 
@@ -722,8 +713,7 @@ sub _AddEvent {
     }
 
     # get current invoker config
-    my $InvokerConfig
-        = $WebserviceData->{Config}->{Requester}->{Invoker}->{ $GetParam{Invoker} };
+    my $InvokerConfig = $WebserviceData->{Config}->{Requester}->{Invoker}->{ $GetParam{Invoker} };
 
     # get Asynchronous Mode
     $GetParam{AsynchronousMode} = $Self->{ParamObject}->GetParam( Param => 'Asynchronous' ) || 0;
@@ -755,8 +745,7 @@ sub _AddEvent {
     my $SelectedEventType = $Self->{ParamObject}->GetParam( Param => 'EventType' );
 
     # stay in edit mode.
-    my $RedirectURL
-        = "Action=AdminGenericInterfaceInvokerDefault;Subaction=Change;WebserviceID=$WebserviceID;"
+    my $RedirectURL = "Action=AdminGenericInterfaceInvokerDefault;Subaction=Change;WebserviceID=$WebserviceID;"
         . "Invoker=$GetParam{Invoker};EventType=$SelectedEventType";
 
     return $Self->{LayoutObject}->Redirect(
@@ -797,8 +786,7 @@ sub _DeleteEvent {
     }
 
     # get current invoker config
-    my $InvokerConfig
-        = $WebserviceData->{Config}->{Requester}->{Invoker}->{ $GetParam{Invoker} };
+    my $InvokerConfig = $WebserviceData->{Config}->{Requester}->{Invoker}->{ $GetParam{Invoker} };
 
     my @Events;
 
