@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -561,6 +561,7 @@ sub _GetParams {
     my $GetParam;
 
     # get parameters from web browser
+    PARAM_NAME:
     for my $ParamName (
         qw(
         DefaultKeyType DefaultKeyMapTo DefaultValueType DefaultValueMapTo
@@ -573,7 +574,7 @@ sub _GetParams {
             if ( $ParamName =~ /(DefaultKeyMapTo|DefaultValueMapTo)/i ) {
                 my $ParamPart = substr( $ParamName, 0, -5 );
                 if ( $Self->{ParamObject}->GetParam( Param => $ParamPart . 'Type' ) ne 'MapTo' ) {
-                    next;
+                    next PARAM_NAME;
                 }
             }
             $GetParam->{Error}->{$ParamName} = 'ServerError';
@@ -586,15 +587,17 @@ sub _GetParams {
 
     # get params for keys
     my $KeyIndex = 0;
+    KEYCOUNTER:
     for my $KeyCounter ( 1 .. $GetParam->{KeyCounter} ) {
-        next if !$Self->{ParamObject}->GetParam( Param => 'KeyIndex' . $KeyCounter );
+        next KEYCOUNTER if !$Self->{ParamObject}->GetParam( Param => 'KeyIndex' . $KeyCounter );
         $KeyIndex++;
+        KEY_ITEM:
         for my $KeyItem (qw(KeyMapTypeStrg KeyName KeyMapNew ValueCounter)) {
             my $KeyAux = $Self->{ParamObject}->GetParam( Param => $KeyItem . $KeyCounter ) // '';
             $GetParam->{ $KeyItem . $KeyIndex } = $KeyAux;
             if ( $KeyItem eq 'ValueCounter' && $KeyAux eq '' ) {
                 $GetParam->{ $KeyItem . $KeyIndex } = 0;
-                next;
+                next KEY_ITEM;
             }
             $GetParam->{Error}->{ $KeyItem . $KeyIndex } = 'ServerError'
                 if $KeyAux eq '';
@@ -602,11 +605,16 @@ sub _GetParams {
 
         # get params for values
         my $ValueIndex = 0;
+        COUNTER:
         for my $ValueCounter ( 1 .. $GetParam->{ 'ValueCounter' . $KeyIndex } ) {
             my $Suffix = $KeyCounter . '_' . $ValueCounter;
-            next
-                if $Self->{ParamObject}->GetParam( Param => 'ValueName' . $Suffix ) eq
-                $Self->{DeletedString};
+            if (
+                $Self->{ParamObject}->GetParam( Param => 'ValueName' . $Suffix ) eq
+                $Self->{DeletedString}
+                )
+            {
+                next COUNTER;
+            }
             $ValueIndex++;
             for my $ValueItem (qw(ValueMapTypeStrg ValueName ValueMapNew)) {
                 my $ValAux = $Self->{ParamObject}->GetParam( Param => $ValueItem . $Suffix ) // '';
