@@ -41,7 +41,7 @@ sub Run {
 
     $Param{ResultFormatStrg} = $Self->{LayoutObject}->BuildSelection(
         Name => 'ResultFormat',
-        Data => [ 'HTML', 'CSV' ],
+        Data => [ 'HTML', 'CSV', 'Excel' ],
     );
 
     if ( !$Self->{ConfigObject}->Get('AdminSelectBox::AllowDatabaseModification') ) {
@@ -117,14 +117,19 @@ sub Run {
                 }
 
                 # if there are any matching rows, they are shown
+                ROW:
                 while ( my @Row = $Self->{DBObject}->FetchrowArray( RowNames => 1 ) ) {
 
                     $MatchesFound = 1;
 
                     # get csv data
-                    if ( $Param{ResultFormat} eq 'CSV' ) {
+                    if (
+                        $Param{ResultFormat} eq 'CSV'
+                        || $Param{ResultFormat} eq 'Excel'
+                        )
+                    {
                         push @Data, \@Row;
-                        next;
+                        next ROW;
                     }
 
                     $Self->{LayoutObject}->Block(
@@ -149,7 +154,6 @@ sub Run {
 
                 # otherwise a no matches found msg is displayed
                 if ( !$MatchesFound ) {
-
                     if ( uc( $Param{SQL} ) !~ m{ \A \s* (?:SELECT|SHOW|DESC) }smx ) {
                         $Self->{LayoutObject}->Block(
                             Name => 'NoSelectResult',
@@ -159,14 +163,12 @@ sub Run {
                         );
                     }
                     else {
-
                         $Self->{LayoutObject}->Block(
                             Name => 'NoMatches',
                             Data => {
                                 Colspan => scalar @Head,
                             },
                         );
-
                     }
                 }
 
@@ -181,7 +183,7 @@ sub Run {
                 my $TimeStamp = $Self->{TimeObject}->CurrentTimestamp();
                 $TimeStamp =~ s/[:-]//g;
                 $TimeStamp =~ s/ /-/;
-                my $FileName = 'admin-select-' . $TimeStamp . '.csv';
+                my $FileName = 'admin-select-' . $TimeStamp;
 
                 # generate csv output
                 if ( $Param{ResultFormat} eq 'CSV' ) {
@@ -191,13 +193,29 @@ sub Run {
                         Separator => $UserCSVSeparator,
                     );
                     return $Self->{LayoutObject}->Attachment(
-                        Filename    => "$FileName",
+                        Filename    => "$FileName" . ".csv",
                         ContentType => 'text/csv',
                         Content     => $CSV,
                         Type        => 'attachment'
                     );
                 }
 
+                # generate Excel output
+                elsif ( $Param{ResultFormat} eq 'Excel' ) {
+                    my $Excel = $Self->{CSVObject}->Array2CSV(
+                        Head   => \@Head,
+                        Data   => \@Data,
+                        Format => 'Excel',
+                    );
+                    return $Self->{LayoutObject}->Attachment(
+                        Filename => "$FileName" . ".xlsx",
+                        ContentType =>
+                            "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
+                        Content => $Excel,
+                        Type    => 'attachment'
+                    );
+                }
+
                 # generate html output
                 my $Output = $Self->{LayoutObject}->Header();
                 $Output .= $Self->{LayoutObject}->NavigationBar();
