@@ -1,6 +1,5 @@
 # --
-# Kernel/Modules/AgentTicketCompose.pm - to compose and send a message
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -439,6 +438,46 @@ sub Run {
 
         my %Error;
 
+        # check some values
+        LINE:
+        for my $Line (qw(To Cc Bcc)) {
+            next LINE if !$GetParam{$Line};
+            for my $Email ( Mail::Address->parse( $GetParam{$Line} ) ) {
+                if ( !$Self->{CheckItemObject}->CheckEmail( Address => $Email->address() ) ) {
+                    $Error{ $Line . 'ErrorType' }
+                        = $Line . $Self->{CheckItemObject}->CheckErrorType() . 'ServerErrorMsg';
+                    $Error{ $Line . 'Invalid' } = 'ServerError';
+                }
+                my $IsLocal = $Self->{SystemAddress}->SystemAddressIsLocalAddress(
+                    Address => $Email->address()
+                );
+                if ($IsLocal) {
+                    $Error{ $Line . 'IsLocalAddress' } = 'ServerError';
+                }
+            }
+        }
+
+        if ( $Error{ToIsLocalAddress} ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'ToIsLocalAddressServerErrorMsg',
+                Data => \%GetParam,
+            );
+        }
+
+        if ( $Error{CcIsLocalAddress} ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'CcIsLocalAddressServerErrorMsg',
+                Data => \%GetParam,
+            );
+        }
+
+        if ( $Error{BccIsLocalAddress} ) {
+            $Self->{LayoutObject}->Block(
+                Name => 'BccIsLocalAddressServerErrorMsg',
+                Data => \%GetParam,
+            );
+        }
+
         # If is an action about attachments
         my $IsUpload = 0;
 
@@ -936,7 +975,7 @@ sub Run {
                             Data        => \%Data,
                             SelectedID  => $GetParam{$Key},
                             Translation => 1,
-                            Max         => 100,
+                            Max         => 150,
                         }
                     );
                 }
@@ -954,7 +993,6 @@ sub Run {
         DYNAMICFIELD:
         for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
             next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
-            next DYNAMICFIELD if $DynamicFieldConfig->{ObjectType} ne 'Ticket';
 
             my $IsACLReducible = $Self->{BackendObject}->HasBehavior(
                 DynamicFieldConfig => $DynamicFieldConfig,
@@ -1261,8 +1299,18 @@ sub Run {
             # check if customer is in recipient list
             if ( $Customer{UserEmail} && $Data{ToEmail} !~ /^\Q$Customer{UserEmail}\E$/i ) {
 
+                if ( $Data{SenderType} eq 'agent' && $DataArticleType !~ m{external} ) {
+                    if ( $Data{To} ) {
+                        $Data{To} .= ', ' . $Customer{UserEmail};
+                    }
+                    else {
+                        $Data{To} = $Customer{UserEmail};
+                    }
+                }
+
                 # replace To with customers database address
-                if ( $Self->{ConfigObject}->Get('Ticket::Frontend::ComposeReplaceSenderAddress') ) {
+                elsif ( $Self->{ConfigObject}->Get('Ticket::Frontend::ComposeReplaceSenderAddress') ) {
+
                     $Output .= $Self->{LayoutObject}->Notify(
                         Data => $Self->{LayoutObject}->{LanguageObject}->Translate(
                             'Address %s replaced with registered customer address.',
