@@ -1,6 +1,5 @@
 # --
-# Kernel/Output/HTML/OutputFilterTextURL.pm - auto URL detection filter
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -46,14 +45,14 @@ sub Pre {
         ( > | < | &gt; | &lt; | )  # $1 greater-than and less-than sign
 
         (                                              #2
-            (?:                                      # http or only www
-                (?: (?: http s? | ftp ) :\/\/) |        # http://,https:// and ftp://
-                (?: (?: \w*www | ftp ) \. \w+ )                 # www.something and ftp.something
+            (?:                                        # http or only www
+                (?: (?: http s? | ftp ) :\/\/)|        # http://,https:// and ftp://
+                (?: (?: \w*www | ftp ) \. \w+ )        # www.something and ftp.something
             )
             .*?               # this part should be better defined!
         )
-        (                               # $3
-            [\?,;!\.\)\]] (?: \s | $ )    # \)\s this construct is because of bug#2450 and bug#7288
+        (                                 # $3
+            [\?,;!\.] (?: \s | $ )        # this construct is because of bug#2450 and bug#7288
             | \s
             | \"
             | &quot;
