@@ -1,6 +1,5 @@
 # --
-# Kernel/Output/HTML/TicketMenuLock.pm
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -12,9 +11,6 @@ package Kernel::Output::HTML::TicketMenuLock;
 use strict;
 use warnings;
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.26 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -23,7 +19,7 @@ sub new {
     bless( $Self, $Type );
 
     # get needed objects
-    for (qw(ConfigObject LogObject DBObject LayoutObject UserID TicketObject)) {
+    for (qw(ConfigObject LogObject DBObject LayoutObject UserID GroupObject TicketObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
 
@@ -35,7 +31,10 @@ sub Run {
 
     # check needed stuff
     if ( !$Param{Ticket} ) {
-        $Self->{LogObject}->Log( Priority => 'error', Message => 'Need Ticket!' );
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => 'Need Ticket!'
+        );
         return;
     }
 
@@ -63,10 +62,40 @@ sub Run {
         return if !$AccessOk;
     }
 
+    # group check
+    if ( $Param{Config}->{Group} ) {
+        my @Items = split /;/, $Param{Config}->{Group};
+        my $AccessOk;
+        GROUP:
+        for my $Item (@Items) {
+            my ( $Permission, $Name ) = split /:/, $Item;
+            if ( !$Permission || !$Name ) {
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message  => "Invalid config for Key Group: '$Item'! "
+                        . "Need something like '\$Permission:\$Group;'",
+                );
+            }
+            my @Groups = $Self->{GroupObject}->GroupMemberList(
+                UserID => $Self->{UserID},
+                Type   => $Permission,
+                Result => 'Name',
+            );
+            next GROUP if !@Groups;
+
+            for my $Group (@Groups) {
+                if ( $Group eq $Name ) {
+                    $AccessOk = 1;
+                    last GROUP;
+                }
+            }
+        }
+        return if !$AccessOk;
+    }
+
     # check acl
-    return
-        if defined $Param{ACL}->{ $Param{Config}->{Action} }
-        && !$Param{ACL}->{ $Param{Config}->{Action} };
+    my %ACLLookup = reverse( %{ $Param{ACL} || {} } );
+    return if ( !$ACLLookup{ $Param{Config}->{Action} } );
 
     # if ticket is locked
     if ( $Param{Ticket}->{Lock} eq 'lock' ) {
@@ -82,7 +111,7 @@ sub Run {
             Name        => 'Unlock',
             Description => 'Unlock to give it back to the queue',
             Link =>
-                'Action=AgentTicketLock;Subaction=Unlock;TicketID=$QData{"TicketID"};$QEnv{"ChallengeTokenParam"}',
+                'Action=AgentTicketLock;Subaction=Unlock;TicketID=[% Data.TicketID | uri %];[% Env("ChallengeTokenParam") | html %]',
         };
     }
 
@@ -94,7 +123,7 @@ sub Run {
         Name        => 'Lock',
         Description => 'Lock it to work on it',
         Link =>
-            'Action=AgentTicketLock;Subaction=Lock;TicketID=$QData{"TicketID"};$QEnv{"ChallengeTokenParam"}',
+            'Action=AgentTicketLock;Subaction=Lock;TicketID=[% Data.TicketID | uri %];[% Env("ChallengeTokenParam") | html %]',
     };
 }
 
