@@ -90,7 +90,7 @@ sub Run {
             Class       => $ClassNew,
             Icon        => $IconNew,
             Link        => $URL . 'Action=AgentTicketResponsibleView;Filter=New',
-            AccessKey   => '',
+            AccessKey   => $Param{Config}->{AccessKeyNew} || '',
         };
     }
     if ($CountReached) {
@@ -101,7 +101,7 @@ sub Run {
             Class       => $ClassReached,
             Icon        => $IconReached,
             Link        => $URL . 'Action=AgentTicketResponsibleView;Filter=ReminderReached',
-            AccessKey   => '',
+            AccessKey   => $Param{Config}->{AccessKeyReached} || '',
         };
     }
     if ($Count) {
@@ -112,7 +112,7 @@ sub Run {
             Class       => $Class,
             Icon        => $Icon,
             Link        => $URL . 'Action=AgentTicketResponsibleView',
-            AccessKey   => 'r',
+            AccessKey   => $Param{Config}->{AccessKey} || '',
         };
     }
     return %Return;
