@@ -11,7 +11,12 @@ package Kernel::System::AutoResponse;
 use strict;
 use warnings;
 
-use Kernel::System::SystemAddress;
+our @ObjectDependencies = (
+    'Kernel::System::DB',
+    'Kernel::System::Encode',
+    'Kernel::System::Log',
+    'Kernel::System::SystemAddress',
+);
 
 =head1 NAME
 
@@ -31,39 +36,9 @@ All auto response functions. E. g. to add auto response or other functions.
 
 create an object
 
-    use Kernel::Config;
-    use Kernel::System::Encode;
-    use Kernel::System::Log;
-    use Kernel::System::Main;
-    use Kernel::System::DB;
-    use Kernel::System::AutoResponse;
-
-    my $ConfigObject = Kernel::Config->new();
-    my $EncodeObject = Kernel::System::Encode->new(
-        ConfigObject => $ConfigObject,
-    );
-    my $LogObject = Kernel::System::Log->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-    );
-    my $MainObject = Kernel::System::Main->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-    );
-    my $DBObject = Kernel::System::DB->new(
-        ConfigObject => $ConfigObject,
-        EncodeObject => $EncodeObject,
-        LogObject    => $LogObject,
-        MainObject   => $MainObject,
-    );
-    my $AutoResponseObject = Kernel::System::AutoResponse->new(
-        ConfigObject => $ConfigObject,
-        LogObject    => $LogObject,
-        DBObject     => $DBObject,
-        MainObject   => $MainObject,
-        EncodeObject => $EncodeObject,
-    );
+    use Kernel::System::ObjectManager;
+    local $Kernel::OM = Kernel::System::ObjectManager->new();
+    my $AutoResponseObject = $Kernel::OM->Get('Kernel::System::AutoReponse');
 
 =cut
 
@@ -74,18 +49,6 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # get needed objects
-    for (qw(ConfigObject LogObject DBObject MainObject EncodeObject)) {
-        if ( $Param{$_} ) {
-            $Self->{$_} = $Param{$_};
-        }
-        else {
-            die "Got no $_!";
-        }
-    }
-
-    $Self->{SystemAddressObject} = $Param{SystemAddressObject} || Kernel::System::SystemAddress->new( %{$Self} );
-
     return $Self;
 }
 
@@ -113,7 +76,7 @@ sub AutoResponseAdd {
     # check needed stuff
     for (qw(Name ValidID Response ContentType AddressID TypeID Charset UserID Subject)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -124,8 +87,11 @@ sub AutoResponseAdd {
     # check if a autoresponse with this name already exits
     return if !$Self->_NameExistsCheck( Name => $Param{Name} );
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # insert into database
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL => 'INSERT INTO auto_response '
             . '(name, valid_id, comments, text0, text1, type_id, system_address_id, '
             . 'charset, content_type,  create_time, create_by, change_time, change_by)'
@@ -139,7 +105,7 @@ sub AutoResponseAdd {
     );
 
     # get id
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => 'SELECT id FROM auto_response WHERE name = ? AND type_id = ? AND'
             . ' system_address_id = ? AND charset = ? AND content_type = ? AND create_by = ?',
         Bind => [
@@ -151,7 +117,7 @@ sub AutoResponseAdd {
 
     # fetch the result
     my $ID;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $ID = $Row[0];
     }
 
@@ -173,15 +139,18 @@ sub AutoResponseGet {
 
     # check needed stuff
     if ( !$Param{ID} ) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => 'Need ID!'
         );
         return;
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # select
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => 'SELECT name, valid_id, comments, text0, text1, type_id, system_address_id, '
             . ' charset, content_type, create_time, create_by, change_time, change_by'
             . ' FROM auto_response WHERE id = ?',
@@ -189,11 +158,14 @@ sub AutoResponseGet {
         Limit => 1,
     );
 
+    # get encode object
+    my $EncodeObject = $Kernel::OM->Get('Kernel::System::Encode');
+
     my %Data;
-    while ( my @Data = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Data = $DBObject->FetchrowArray() ) {
 
         # convert body
-        $Data[3] = $Self->{EncodeObject}->Convert(
+        $Data[3] = $EncodeObject->Convert(
             Text  => $Data[3],
             From  => $Data[7],
             To    => 'utf-8',
@@ -201,7 +173,7 @@ sub AutoResponseGet {
         );
 
         # convert subject
-        $Data[4] = $Self->{EncodeObject}->Convert(
+        $Data[4] = $EncodeObject->Convert(
             Text  => $Data[4],
             From  => $Data[7],
             To    => 'utf-8',
@@ -261,7 +233,7 @@ sub AutoResponseUpdate {
     # check needed stuff
     for (qw(ID Name ValidID Response AddressID Charset ContentType UserID Subject)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -276,7 +248,7 @@ sub AutoResponseUpdate {
     );
 
     # update the database
-    return if !$Self->{DBObject}->Do(
+    return if !$Kernel::OM->Get('Kernel::System::DB')->Do(
         SQL => 'UPDATE auto_response SET '
             . 'name = ?, text0 = ?, comments = ?, text1 = ?, type_id = ?, '
             . 'system_address_id = ?, charset = ?, content_type = ?, valid_id = ?, '
@@ -331,7 +303,7 @@ sub AutoResponseGetByTypeQueueID {
     # check needed stuff
     for (qw(QueueID Type)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -339,8 +311,11 @@ sub AutoResponseGetByTypeQueueID {
         }
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # SQL query
-    return if !$Self->{DBObject}->Prepare(
+    return if !$DBObject->Prepare(
         SQL => 'SELECT ar.text0, ar.text1, ar.charset, ar.content_type, ar.system_address_id FROM '
             . 'auto_response_type art, auto_response ar, queue_auto_response qar '
             . 'WHERE qar.queue_id = ? AND art.id = ar.type_id AND '
@@ -353,7 +328,7 @@ sub AutoResponseGetByTypeQueueID {
 
     # fetch the result
     my %Data;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         $Data{Text}            = $Row[0];
         $Data{Subject}         = $Row[1];
         $Data{Charset}         = $Row[2];
@@ -365,7 +340,7 @@ sub AutoResponseGetByTypeQueueID {
     return if !%Data;
 
     # get sender attributes
-    my %Address = $Self->{SystemAddressObject}->SystemAddressGet(
+    my %Address = $Kernel::OM->Get('Kernel::System::SystemAddress')->SystemAddressGet(
         ID => $Data{SystemAddressID},
     );
 
@@ -395,7 +370,7 @@ Return example:
 sub AutoResponseList {
     my ( $Self, %Param ) = @_;
 
-    return $Self->{DBObject}->GetTableData(
+    return $Kernel::OM->Get('Kernel::System::DB')->GetTableData(
         What  => 'id, name, id',
         Valid => 0,
         Clamp => 1,
@@ -424,7 +399,7 @@ Return example:
 sub AutoResponseTypeList {
     my ( $Self, %Param ) = @_;
 
-    return $Self->{DBObject}->GetTableData(
+    return $Kernel::OM->Get('Kernel::System::DB')->GetTableData(
         What  => 'id, name',
         Valid => 1,
         Clamp => 1,
@@ -452,7 +427,7 @@ sub AutoResponseQueue {
     # check needed stuff
     for (qw(QueueID AutoResponseIDs UserID)) {
         if ( !$Param{$_} ) {
-            $Self->{LogObject}->Log(
+            $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
                 Message  => "Need $_!"
             );
@@ -460,8 +435,11 @@ sub AutoResponseQueue {
         }
     }
 
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # store queue:auto response relations
-    return if !$Self->{DBObject}->Do(
+    return if !$DBObject->Do(
         SQL  => 'DELETE FROM queue_auto_response WHERE queue_id = ?',
         Bind => [ \$Param{QueueID} ],
     );
@@ -471,7 +449,7 @@ sub AutoResponseQueue {
 
         next NEWID if !$NewID;
 
-        $Self->{DBObject}->Do(
+        $DBObject->Do(
             SQL => 'INSERT INTO queue_auto_response (queue_id, auto_response_id, '
                 . 'create_time, create_by, change_time, change_by) VALUES '
                 . '(?, ?, current_timestamp, ?, current_timestamp, ?)',
@@ -500,21 +478,24 @@ return if another autoresponse with this name already exits
 sub _NameExistsCheck {
     my ( $Self, %Param ) = @_;
 
-    return if !$Self->{DBObject}->Prepare(
+    # get database object
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    return if !$DBObject->Prepare(
         SQL  => 'SELECT id FROM auto_response WHERE name = ?',
         Bind => [ \$Param{Name} ],
     );
 
     # fetch the result
     my $Flag;
-    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+    while ( my @Row = $DBObject->FetchrowArray() ) {
         if ( !$Param{ID} || $Param{ID} ne $Row[0] ) {
             $Flag = 1;
         }
     }
 
     if ($Flag) {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message  => "An Auto-Response with name '$Param{Name}' already exists!",
         );
