@@ -1,6 +1,5 @@
 # --
-# Kernel/System/CSV.pm - all csv functions
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -119,7 +118,9 @@ sub Array2CSV {
         my @ColumnLengths;
         my $Row = 0;
         for my $DataRaw ( \@Head, @Data ) {
+            COL:
             for my $Col ( 0 .. ( scalar @{ $DataRaw // [] } ) - 1 ) {
+                next COL if !defined( $DataRaw->[$Col] );
                 my $CellLength = length( $DataRaw->[$Col] );
                 $CellLength = 30 if ( $CellLength > 30 );
                 if ( !defined $ColumnLengths[$Col] || $ColumnLengths[$Col] < $CellLength ) {
@@ -219,24 +220,14 @@ Returns an array with parsed csv data.
 sub CSV2Array {
     my ( $Self, %Param ) = @_;
 
-    # get separator
-    if ( !defined $Param{Separator} || $Param{Separator} eq '' ) {
-        $Param{Separator} = ';';
-    }
-
-    # get separator
-    if ( !defined $Param{Quote} ) {
-        $Param{Quote} = '"';
-    }
-
     # create new csv backend object
     my $CSV = Text::CSV->new(
         {
 
-            #            quote_char          => $Param{Quote},
-            #            escape_char         => $Param{Quote},
-            sep_char            => $Param{Separator},
-            eol                 => '',
+            quote_char => $Param{Quote} // '"',
+            escape_char => $Param{Quote}     || '"',
+            sep_char    => $Param{Separator} || ";",
+            eol         => '',
             always_quote        => 0,
             binary              => 1,
             keep_meta_info      => 0,
@@ -250,20 +241,25 @@ sub CSV2Array {
     # do some dos/unix file conversions
     $Param{String} =~ s/(\n\r|\r\r\n|\r\n|\r)/\n/g;
 
-    # if you change the split options, remember that each value can include \n
     my @Array;
-    my @Lines = split /$Param{Quote}\n/, $Param{String};
-    for my $Line (@Lines) {
-        if ( $CSV->parse( $Line . $Param{Quote} ) ) {
-            my @Fields = $CSV->fields();
-            push @Array, \@Fields;
-        }
-        else {
-            $Kernel::OM->Get('Kernel::System::Log')->Log(
-                Priority => 'error',
-                Message  => 'Failed to parse line: ' . $CSV->error_input(),
-            );
-        }
+
+    # parse all CSV data line by line (allows newlines in data fields)
+    my $LineCounter = 1;
+    open my $FileHandle, '<', \$Param{String};    ## no critic
+    while ( my $ColRef = $CSV->getline($FileHandle) ) {
+        push @Array, $ColRef;
+        $LineCounter++;
+    }
+
+    # log error if occurred and exit
+    if ( !$CSV->eof() ) {
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
+            Priority => 'error',
+            Message  => 'Failed to parse CSV line ' . $LineCounter
+                . ' (input: ' . $CSV->error_input()
+                . ', error: ' . $CSV->error_diag() . ')',
+        );
+        return;
     }
 
     return \@Array;
