@@ -1,6 +1,5 @@
 # --
-# Kernel/System/JSON.pm - Wrapper functions for encoding and decoding JSON
-# Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -96,6 +95,17 @@ sub Encode {
     # get JSON-encoded presentation of perl structure
     my $JSONEncoded = $JSONObject->encode( $Param{Data} ) || '""';
 
+    # Special handling for unicode line terminators (\u2028 and \u2029),
+    # they are allowed in JSON but not in JavaScript
+    # see: http://timelessrepo.com/json-isnt-a-javascript-subset
+    #
+    # Should be fixed in JSON module, but bug report is still open
+    # see: https://rt.cpan.org/Public/Bug/Display.html?id=75755
+    #
+    # Therefore must be encoded manually
+    $JSONEncoded =~ s/\x{2028}/\\u2028/xmsg;
+    $JSONEncoded =~ s/\x{2029}/\\u2029/xmsg;
+
     return $JSONEncoded;
 }
 
@@ -134,6 +144,11 @@ sub Decode {
         return;
     }
 
+    # sanitize leftover boolean objects
+    $Scalar = $Self->_BooleansProcess(
+        JSON => $Scalar,
+    );
+
     return $Scalar;
 }
 
@@ -155,7 +170,10 @@ as a JavaScript string instead.
 =cut
 
 sub True {
-    return JSON::true();
+
+    # Use constant instead of JSON::false() as this can cause nasty problems with JSON::XS on some platforms.
+    # (encountered object '1', but neither allow_blessed, convert_blessed nor allow_tags settings are enabled)
+    return \1;
 }
 
 =item False()
@@ -165,11 +183,61 @@ like C<True()>, but for a false boolean value.
 =cut
 
 sub False {
-    return JSON::false();
+
+    # Use constant instead of JSON::false() as this can cause nasty problems with JSON::XS on some platforms.
+    # (encountered object '0', but neither allow_blessed, convert_blessed nor allow_tags settings are enabled)
+    return \0;
+}
+
+=begin Internal:
+
+=cut
+
+=item _BooleansProcess()
+
+decode boolean values leftover from JSON decoder to simple scalar values
+
+    my $ProcessedJSON = $JSONObject->_BooleansProcess(
+        JSON => $JSONData,
+    );
+
+=cut
+
+sub _BooleansProcess {
+    my ( $Self, %Param ) = @_;
+
+    # convert scalars if needed
+    if ( JSON::is_bool( $Param{JSON} ) ) {
+        $Param{JSON} = ( $Param{JSON} ? 1 : 0 );
+    }
+
+    # recurse into arrays
+    elsif ( ref $Param{JSON} eq 'ARRAY' ) {
+
+        for my $Value ( @{ $Param{JSON} } ) {
+            $Value = $Self->_BooleansProcess(
+                JSON => $Value,
+            );
+        }
+    }
+
+    # recurse into hashes
+    elsif ( ref $Param{JSON} eq 'HASH' ) {
+
+        for my $Value ( values %{ $Param{JSON} } ) {
+            $Value = $Self->_BooleansProcess(
+                JSON => $Value,
+            );
+        }
+    }
+
+    return $Param{JSON};
 }
 
 1;
 
+=end Internal:
+
 =back
 
 =head1 TERMS AND CONDITIONS
