@@ -1,6 +1,5 @@
 # --
-# Kernel/System/Stats/Dynamic/TicketList.pm - reporting via ticket lists
-# Copyright (C) 2001-2014 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -13,15 +12,28 @@ use strict;
 use warnings;
 
 use List::Util qw( first );
-use Kernel::System::Queue;
-use Kernel::System::Service;
-use Kernel::System::SLA;
-use Kernel::System::Ticket;
-use Kernel::System::Type;
-use Kernel::System::DynamicField;
-use Kernel::System::DynamicField::Backend;
+
 use Kernel::System::VariableCheck qw(:all);
 
+our @ObjectDependencies = (
+    'Kernel::Config',
+    'Kernel::Language',
+    'Kernel::System::DB',
+    'Kernel::System::DynamicField',
+    'Kernel::System::DynamicField::Backend',
+    'Kernel::System::Lock',
+    'Kernel::System::Log',
+    'Kernel::System::Priority',
+    'Kernel::System::Queue',
+    'Kernel::System::Service',
+    'Kernel::System::SLA',
+    'Kernel::System::State',
+    'Kernel::System::Ticket',
+    'Kernel::System::Time',
+    'Kernel::System::Type',
+    'Kernel::System::User',
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -29,29 +41,8 @@ sub new {
     my $Self = {};
     bless( $Self, $Type );
 
-    # check needed objects
-    for my $Object (
-        qw(DBObject ConfigObject LogObject UserObject TimeObject MainObject EncodeObject)
-        )
-    {
-        $Self->{$Object} = $Param{$Object} || die "Got no $Object!";
-    }
-
-    # use ticket object if it comes in the params
-    $Self->{TicketObject} = $Param{TicketObject} // Kernel::System::Ticket->new( %{$Self} );
-
-    $Self->{QueueObject}        = Kernel::System::Queue->new( %{$Self} );
-    $Self->{StateObject}        = Kernel::System::State->new( %{$Self} );
-    $Self->{PriorityObject}     = Kernel::System::Priority->new( %{$Self} );
-    $Self->{LockObject}         = Kernel::System::Lock->new( %{$Self} );
-    $Self->{ServiceObject}      = Kernel::System::Service->new( %{$Self} );
-    $Self->{SLAObject}          = Kernel::System::SLA->new( %{$Self} );
-    $Self->{TypeObject}         = Kernel::System::Type->new( %{$Self} );
-    $Self->{DynamicFieldObject} = Kernel::System::DynamicField->new( %{$Self} );
-    $Self->{BackendObject}      = Kernel::System::DynamicField::Backend->new( %{$Self} );
-
     # get the dynamic fields for ticket object
-    $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
+    $Self->{DynamicField} = $Kernel::OM->Get('Kernel::System::DynamicField')->DynamicFieldListGet(
         Valid      => 1,
         ObjectType => ['Ticket'],
     );
@@ -78,41 +69,50 @@ sub GetObjectBehaviours {
 sub GetObjectAttributes {
     my ( $Self, %Param ) = @_;
 
+    # get needed objects
+    my $ConfigObject   = $Kernel::OM->Get('Kernel::Config');
+    my $UserObject     = $Kernel::OM->Get('Kernel::System::User');
+    my $QueueObject    = $Kernel::OM->Get('Kernel::System::Queue');
+    my $TicketObject   = $Kernel::OM->Get('Kernel::System::Ticket');
+    my $StateObject    = $Kernel::OM->Get('Kernel::System::State');
+    my $PriorityObject = $Kernel::OM->Get('Kernel::System::Priority');
+    my $LockObject     = $Kernel::OM->Get('Kernel::System::Lock');
+
     my $ValidAgent = 0;
     if (
-        defined $Self->{ConfigObject}->Get('Stats::UseInvalidAgentInStats')
-        && ( $Self->{ConfigObject}->Get('Stats::UseInvalidAgentInStats') == 0 )
+        defined $ConfigObject->Get('Stats::UseInvalidAgentInStats')
+        && ( $ConfigObject->Get('Stats::UseInvalidAgentInStats') == 0 )
         )
     {
         $ValidAgent = 1;
     }
 
     # get user list
-    my %UserList = $Self->{UserObject}->UserList(
+    my %UserList = $UserObject->UserList(
         Type  => 'Long',
         Valid => $ValidAgent,
     );
 
     # get state list
-    my %StateList = $Self->{StateObject}->StateList(
+    my %StateList = $StateObject->StateList(
         UserID => 1,
     );
 
     # get state type list
-    my %StateTypeList = $Self->{StateObject}->StateTypeList(
+    my %StateTypeList = $StateObject->StateTypeList(
         UserID => 1,
     );
 
     # get queue list
-    my %QueueList = $Self->{QueueObject}->GetAllQueues();
+    my %QueueList = $QueueObject->GetAllQueues();
 
     # get priority list
-    my %PriorityList = $Self->{PriorityObject}->PriorityList(
+    my %PriorityList = $PriorityObject->PriorityList(
         UserID => 1,
     );
 
     # get lock list
-    my %LockList = $Self->{LockObject}->LockList(
+    my %LockList = $LockObject->LockList(
         UserID => 1,
     );
 
@@ -126,8 +126,10 @@ sub GetObjectAttributes {
     );
 
     my %TicketAttributes = %{ $Self->_TicketAttributes() };
-    my %OrderBy
-        = map { $_ => $TicketAttributes{$_} } grep { $_ ne 'Number' } keys %TicketAttributes;
+    my %OrderBy = map { $_ => $TicketAttributes{$_} } grep { $_ ne 'Number' } keys %TicketAttributes;
+
+    # get dynamic field backend object
+    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
 
     # remove non sortable (and orderable) Dynamic Fields
     DYNAMICFIELD:
@@ -136,7 +138,7 @@ sub GetObjectAttributes {
         next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
 
         # check if dynamic field is sortable
-        my $IsSortable = $Self->{BackendObject}->HasBehavior(
+        my $IsSortable = $DynamicFieldBackendObject->HasBehavior(
             DynamicFieldConfig => $DynamicFieldConfig,
             Behavior           => 'IsSortable',
         );
@@ -363,6 +365,32 @@ sub GetObjectAttributes {
                 TimeStop  => 'TicketCreateTimeOlderDate',
             },
         },
+        {
+            Name             => 'Last changed times',
+            UseAsXvalue      => 0,
+            UseAsValueSeries => 0,
+            UseAsRestriction => 1,
+            Element          => 'LastChangeTime',
+            TimePeriodFormat => 'DateInputFormat',      # 'DateInputFormatLong',
+            Block            => 'Time',
+            Values           => {
+                TimeStart => 'TicketLastChangeTimeNewerDate',
+                TimeStop  => 'TicketLastChangeTimeOlderDate',
+            },
+        },
+        {
+            Name             => 'Change times',
+            UseAsXvalue      => 0,
+            UseAsValueSeries => 0,
+            UseAsRestriction => 1,
+            Element          => 'ChangeTime',
+            TimePeriodFormat => 'DateInputFormat',    # 'DateInputFormatLong',
+            Block            => 'Time',
+            Values           => {
+                TimeStart => 'TicketChangeTimeNewerDate',
+                TimeStop  => 'TicketChangeTimeOlderDate',
+            },
+        },
         {
             Name             => 'Close Time',
             UseAsXvalue      => 0,
@@ -443,15 +471,16 @@ sub GetObjectAttributes {
         },
     );
 
-    if ( $Self->{ConfigObject}->Get('Ticket::Service') ) {
+    if ( $ConfigObject->Get('Ticket::Service') ) {
 
         # get service list
-        my %Service = $Self->{ServiceObject}->ServiceList(
-            UserID => 1,
+        my %Service = $Kernel::OM->Get('Kernel::System::Service')->ServiceList(
+            KeepChildren => $ConfigObject->Get('Ticket::Service::KeepChildren'),
+            UserID       => 1,
         );
 
         # get sla list
-        my %SLA = $Self->{SLAObject}->SLAList(
+        my %SLA = $Kernel::OM->Get('Kernel::System::SLA')->SLAList(
             UserID => 1,
         );
 
@@ -482,10 +511,10 @@ sub GetObjectAttributes {
         unshift @ObjectAttributes, @ObjectAttributeAdd;
     }
 
-    if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
+    if ( $ConfigObject->Get('Ticket::Type') ) {
 
         # get ticket type list
-        my %Type = $Self->{TypeObject}->TypeList(
+        my %Type = $Kernel::OM->Get('Kernel::System::Type')->TypeList(
             UserID => 1,
         );
 
@@ -503,7 +532,7 @@ sub GetObjectAttributes {
         unshift @ObjectAttributes, \%ObjectAttribute1;
     }
 
-    if ( $Self->{ConfigObject}->Get('Stats::UseAgentElementInStats') ) {
+    if ( $ConfigObject->Get('Stats::UseAgentElementInStats') ) {
 
         my @ObjectAttributeAdd = (
             {
@@ -541,17 +570,19 @@ sub GetObjectAttributes {
         push @ObjectAttributes, @ObjectAttributeAdd;
     }
 
-    if ( $Self->{ConfigObject}->Get('Stats::CustomerIDAsMultiSelect') ) {
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
+    if ( $ConfigObject->Get('Stats::CustomerIDAsMultiSelect') ) {
 
         # Get CustomerID
         # (This way also can be the solution for the CustomerUserID)
-        $Self->{DBObject}->Prepare(
+        $DBObject->Prepare(
             SQL => "SELECT DISTINCT customer_id FROM ticket",
         );
 
         # fetch the result
         my %CustomerID;
-        while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        while ( my @Row = $DBObject->FetchrowArray() ) {
             if ( $Row[0] ) {
                 $CustomerID{ $Row[0] } = $Row[0];
             }
@@ -583,7 +614,7 @@ sub GetObjectAttributes {
         push @ObjectAttributes, \%ObjectAttribute;
     }
 
-    if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+    if ( $ConfigObject->Get('Ticket::ArchiveSystem') ) {
 
         my %ObjectAttribute = (
             Name             => 'Archive Search',
@@ -609,7 +640,7 @@ sub GetObjectAttributes {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
 
         # skip all fields not designed to be supported by statistics
-        my $IsStatsCondition = $Self->{BackendObject}->HasBehavior(
+        my $IsStatsCondition = $DynamicFieldBackendObject->HasBehavior(
             DynamicFieldConfig => $DynamicFieldConfig,
             Behavior           => 'IsStatsCondition',
         );
@@ -618,7 +649,7 @@ sub GetObjectAttributes {
 
         my $PossibleValuesFilter;
 
-        my $IsACLReducible = $Self->{BackendObject}->HasBehavior(
+        my $IsACLReducible = $DynamicFieldBackendObject->HasBehavior(
             DynamicFieldConfig => $DynamicFieldConfig,
             Behavior           => 'IsACLReducible',
         );
@@ -626,7 +657,7 @@ sub GetObjectAttributes {
         if ($IsACLReducible) {
 
             # get PossibleValues
-            my $PossibleValues = $Self->{BackendObject}->PossibleValuesGet(
+            my $PossibleValues = $DynamicFieldBackendObject->PossibleValuesGet(
                 DynamicFieldConfig => $DynamicFieldConfig,
             );
 
@@ -635,7 +666,7 @@ sub GetObjectAttributes {
             @AclData{ keys %AclData } = keys %AclData;
 
             # set possible values filter from ACLs
-            my $ACL = $Self->{TicketObject}->TicketAcl(
+            my $ACL = $TicketObject->TicketAcl(
                 Action        => 'AgentStats',
                 Type          => 'DynamicField_' . $DynamicFieldConfig->{Name},
                 ReturnType    => 'Ticket',
@@ -644,22 +675,55 @@ sub GetObjectAttributes {
                 UserID        => 1,
             );
             if ($ACL) {
-                my %Filter = $Self->{TicketObject}->TicketAclData();
+                my %Filter = $TicketObject->TicketAclData();
 
                 # convert Filer key => key back to key => value using map
-                %{$PossibleValuesFilter}
-                    = map { $_ => $PossibleValues->{$_} } keys %Filter;
+                %{$PossibleValuesFilter} = map { $_ => $PossibleValues->{$_} } keys %Filter;
             }
         }
 
         # get dynamic field stats parameters
-        my $DynamicFieldStatsParameter = $Self->{BackendObject}->StatsFieldParameterBuild(
+        my $DynamicFieldStatsParameter = $DynamicFieldBackendObject->StatsFieldParameterBuild(
             DynamicFieldConfig   => $DynamicFieldConfig,
             PossibleValuesFilter => $PossibleValuesFilter,
         );
 
         if ( IsHashRefWithData($DynamicFieldStatsParameter) ) {
-            if ( IsHashRefWithData( $DynamicFieldStatsParameter->{Values} ) ) {
+
+            # backward compatibility
+            if ( !$DynamicFieldStatsParameter->{Block} ) {
+                $DynamicFieldStatsParameter->{Block} = 'InputField';
+                if ( IsHashRefWithData( $DynamicFieldStatsParameter->{Values} ) ) {
+                    $DynamicFieldStatsParameter->{Block} = 'MultiSelectField';
+                }
+            }
+
+            if ( $DynamicFieldStatsParameter->{Block} eq 'Time' ) {
+
+                # create object attributes (date/time fields)
+                my $TimePeriodFormat = $DynamicFieldStatsParameter->{TimePeriodFormat} || 'DateInputFormatLong';
+
+                my %ObjectAttribute = (
+                    Name             => $DynamicFieldStatsParameter->{Name},
+                    UseAsXvalue      => 0,
+                    UseAsValueSeries => 0,
+                    UseAsRestriction => 1,
+                    Element          => $DynamicFieldStatsParameter->{Element},
+                    TimePeriodFormat => $TimePeriodFormat,
+                    Block            => $DynamicFieldStatsParameter->{Block},
+                    TimePeriodFormat => $TimePeriodFormat,
+                    Values           => {
+                        TimeStart =>
+                            $DynamicFieldStatsParameter->{Element}
+                            . '_GreaterThanEquals',
+                        TimeStop =>
+                            $DynamicFieldStatsParameter->{Element}
+                            . '_SmallerThanEquals',
+                    },
+                );
+                push @ObjectAttributes, \%ObjectAttribute;
+            }
+            elsif ( $DynamicFieldStatsParameter->{Block} eq 'MultiSelectField' ) {
 
                 # create object attributes (multiple values)
                 my %ObjectAttribute = (
@@ -668,7 +732,7 @@ sub GetObjectAttributes {
                     UseAsValueSeries => 0,
                     UseAsRestriction => 1,
                     Element          => $DynamicFieldStatsParameter->{Element},
-                    Block            => 'MultiSelectField',
+                    Block            => $DynamicFieldStatsParameter->{Block},
                     Values           => $DynamicFieldStatsParameter->{Values},
                     Translation      => 0,
                     IsDynamicField   => 1,
@@ -685,7 +749,7 @@ sub GetObjectAttributes {
                     UseAsValueSeries => 0,
                     UseAsRestriction => 1,
                     Element          => $DynamicFieldStatsParameter->{Element},
-                    Block            => 'InputField',
+                    Block            => $DynamicFieldStatsParameter->{Block},
                 );
                 push @ObjectAttributes, \%ObjectAttribute;
             }
@@ -700,6 +764,8 @@ sub GetStatTable {
     my %TicketAttributes = map { $_ => 1 } @{ $Param{XValue}{SelectedValues} };
     my $SortedAttributesRef = $Self->_SortedAttributes();
 
+    my $DBObject = $Kernel::OM->Get('Kernel::System::DB');
+
     # check if a enumeration is requested
     my $AddEnumeration = 0;
     if ( $TicketAttributes{Number} ) {
@@ -719,9 +785,7 @@ sub GetStatTable {
         OrderBy => $OrderBy,
     );
 
-    #
     # escape search attributes for ticket search
-    #
     my %AttributesToEscape = (
         'CustomerID' => 1,
         'Title'      => 1,
@@ -735,21 +799,29 @@ sub GetStatTable {
         if ( ref $Param{Restrictions}->{$Key} ) {
             if ( ref $Param{Restrictions}->{$Key} eq 'ARRAY' ) {
                 $Param{Restrictions}->{$Key} = [
-                    map { $Self->{DBObject}->QueryStringEscape( QueryString => $_ ) }
+                    map { $DBObject->QueryStringEscape( QueryString => $_ ) }
                         @{ $Param{Restrictions}->{$Key} }
                 ];
             }
         }
         else {
-            $Param{Restrictions}->{$Key} = $Self->{DBObject}->QueryStringEscape(
+            $Param{Restrictions}->{$Key} = $DBObject->QueryStringEscape(
                 QueryString => $Param{Restrictions}->{$Key}
             );
         }
     }
 
+    # get dynamic field backend object
+    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
+
     my %DynamicFieldRestrictions;
     for my $ParameterName ( sort keys %{ $Param{Restrictions} } ) {
-        if ( $ParameterName =~ m{\A DynamicField_ ( [a-zA-Z\d]+ ) \z}xms ) {
+        if (
+            $ParameterName =~ m{ \A DynamicField_ ( [a-zA-Z\d]+ ) (?: _ ( [a-zA-Z\d]+ ) )? \z }xms
+            )
+        {
+            my $FieldName = $1;
+            my $Operator  = $2;
 
             # loop over the dynamic fields configured
             DYNAMICFIELD:
@@ -757,12 +829,12 @@ sub GetStatTable {
                 next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
                 next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
 
-                # skip all fields that does not match with current field name ($1)
+                # skip all fields that do not match with current field name
                 # without the 'DynamicField_' prefix
-                next DYNAMICFIELD if $DynamicFieldConfig->{Name} ne $1;
+                next DYNAMICFIELD if $DynamicFieldConfig->{Name} ne $FieldName;
 
                 # skip all fields not designed to be supported by statistics
-                my $IsStatsCondition = $Self->{BackendObject}->HasBehavior(
+                my $IsStatsCondition = $DynamicFieldBackendObject->HasBehavior(
                     DynamicFieldConfig => $DynamicFieldConfig,
                     Behavior           => 'IsStatsCondition',
                 );
@@ -770,14 +842,25 @@ sub GetStatTable {
                 next DYNAMICFIELD if !$IsStatsCondition;
 
                 # get new search parameter
-                my $DynamicFieldStatsSearchParameter
-                    = $Self->{BackendObject}->StatsSearchFieldParameterBuild(
+                my $DynamicFieldStatsSearchParameter = $DynamicFieldBackendObject->StatsSearchFieldParameterBuild(
                     DynamicFieldConfig => $DynamicFieldConfig,
                     Value              => $Param{Restrictions}->{$ParameterName},
-                    );
+                    Operator           => $Operator,
+                );
 
                 # add new search parameter
-                $DynamicFieldRestrictions{$ParameterName} = $DynamicFieldStatsSearchParameter;
+                if ( !IsHashRefWithData( $DynamicFieldRestrictions{"DynamicField_$FieldName"} ) ) {
+                    $DynamicFieldRestrictions{"DynamicField_$FieldName"} =
+                        $DynamicFieldStatsSearchParameter;
+                }
+
+                # extend search parameter
+                elsif ( IsHashRefWithData($DynamicFieldStatsSearchParameter) ) {
+                    $DynamicFieldRestrictions{"DynamicField_$FieldName"} = {
+                        %{ $DynamicFieldRestrictions{"DynamicField_$FieldName"} },
+                        %{$DynamicFieldStatsSearchParameter},
+                    };
+                }
             }
         }
     }
@@ -794,6 +877,9 @@ sub GetStatTable {
         $Param{Restrictions}{Limit} = 100_000_000;
     }
 
+    # get state object
+    my $StateObject = $Kernel::OM->Get('Kernel::System::State');
+
     # OlderTicketsExclude for historic searches
     # takes tickets that were closed before the
     # start of the searched time periode
@@ -803,16 +889,19 @@ sub GetStatTable {
     # takes tickets that were created after the
     # searched time periode
     my %NewerTicketsExclude;
-    my %StateList = $Self->{StateObject}->StateList( UserID => 1 );
+    my %StateList = $StateObject->StateList( UserID => 1 );
+
+    # get time object
+    my $TimeObject = $Kernel::OM->Get('Kernel::System::Time');
 
     # UnixTimeStart & End:
     # The Time periode the historic search is executed
     # if no time periode has been selected we take
     # Unixtime 0 as StartTime and SystemTime as EndTime
     my $UnixTimeStart = 0;
-    my $UnixTimeEnd   = $Self->{TimeObject}->SystemTime();
+    my $UnixTimeEnd   = $TimeObject->SystemTime();
 
-    if ( $Self->{ConfigObject}->Get('Ticket::ArchiveSystem') ) {
+    if ( $Kernel::OM->Get('Kernel::Config')->Get('Ticket::ArchiveSystem') ) {
         $Param{Restrictions}->{SearchInArchive} ||= '';
         if ( $Param{Restrictions}->{SearchInArchive} eq 'AllTickets' ) {
             $Param{Restrictions}->{ArchiveFlags} = [ 'y', 'n' ];
@@ -825,13 +914,16 @@ sub GetStatTable {
         }
     }
 
+    # get ticket object
+    my $TicketObject = $Kernel::OM->Get('Kernel::System::Ticket');
+
     if ( $Param{Restrictions}->{HistoricTimeRangeTimeNewerDate} ) {
 
         # Find tickets that were closed before the start of our
         # HistoricTimeRangeTimeNewerDate, these have to be excluded.
         # In order to reduce it quickly we reformat the result array
         # to a hash.
-        my @OldToExclude = $Self->{TicketObject}->TicketSearch(
+        my @OldToExclude = $TicketObject->TicketSearch(
             UserID                   => 1,
             Result                   => 'ARRAY',
             Permission               => 'ro',
@@ -840,7 +932,7 @@ sub GetStatTable {
             Limit                    => 100_000_000,
         );
         %OlderTicketsExclude = map { $_ => 1 } @OldToExclude;
-        $UnixTimeStart = $Self->{TimeObject}->TimeStamp2SystemTime(
+        $UnixTimeStart = $TimeObject->TimeStamp2SystemTime(
             String => $Param{Restrictions}->{HistoricTimeRangeTimeNewerDate}
         );
     }
@@ -850,7 +942,7 @@ sub GetStatTable {
         # HistoricTimeRangeTimeOlderDate, these have to be excluded
         # in order to reduce it quickly we reformat the result array
         # to a hash.
-        my @NewToExclude = $Self->{TicketObject}->TicketSearch(
+        my @NewToExclude = $TicketObject->TicketSearch(
             UserID                    => 1,
             Result                    => 'ARRAY',
             Permission                => 'ro',
@@ -859,13 +951,13 @@ sub GetStatTable {
             Limit                     => 100_000_000,
         );
         %NewerTicketsExclude = map { $_ => 1 } @NewToExclude;
-        $UnixTimeEnd = $Self->{TimeObject}->TimeStamp2SystemTime(
+        $UnixTimeEnd = $TimeObject->TimeStamp2SystemTime(
             String => $Param{Restrictions}->{HistoricTimeRangeTimeOlderDate}
         );
     }
 
     # get the involved tickets
-    my @TicketIDs = $Self->{TicketObject}->TicketSearch(
+    my @TicketIDs = $TicketObject->TicketSearch(
         UserID     => 1,
         Result     => 'ARRAY',
         Permission => 'ro',
@@ -931,7 +1023,7 @@ sub GetStatTable {
             #     6 => "removed",
             #     7 => "merged",
             # );
-            my %ListType = $Self->{StateObject}->StateTypeList(
+            my %ListType = $StateObject->StateTypeList(
                 UserID => 1,
             );
 
@@ -953,7 +1045,7 @@ sub GetStatTable {
             # And now get the StatesByType
             # Result is a Hash {ID => StateName,}
             my @StateTypes = keys %StateTypeHash;
-            %StateIDs = $Self->{StateObject}->StateGetStatesByType(
+            %StateIDs = $StateObject->StateGetStatesByType(
                 StateType => [ keys %StateTypeHash ],
                 Result    => 'HASH',
             );
@@ -978,7 +1070,7 @@ sub GetStatTable {
 
         $SQL = 'SELECT ticket_id, state_id, create_time FROM ticket_history WHERE ' . $SQL;
 
-        $Self->{DBObject}->Prepare( SQL => $SQL );
+        $DBObject->Prepare( SQL => $SQL );
 
         # Structure:
         # Stores the last TicketState:
@@ -986,12 +1078,12 @@ sub GetStatTable {
         my %FoundTickets;
 
         # fetch the result
-        while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        while ( my @Row = $DBObject->FetchrowArray() ) {
             if ( $Row[0] ) {
                 my $TicketID    = $Row[0];
                 my $StateID     = $Row[1];
                 my $RowTime     = $Row[2];
-                my $RowTimeUnix = $Self->{TimeObject}->TimeStamp2SystemTime(
+                my $RowTimeUnix = $TimeObject->TimeStamp2SystemTime(
                     String => $Row[2],
                 );
 
@@ -1074,7 +1166,7 @@ sub GetStatTable {
     my @StatArray;
     for my $TicketID (@TicketIDs) {
         my @ResultRow;
-        my %Ticket = $Self->{TicketObject}->TicketGet(
+        my %Ticket = $TicketObject->TicketGet(
             TicketID      => $TicketID,
             UserID        => 1,
             Extended      => $Extended,
@@ -1083,8 +1175,7 @@ sub GetStatTable {
 
         # add the accounted time if needed
         if ( $TicketAttributes{AccountedTime} ) {
-            $Ticket{AccountedTime}
-                = $Self->{TicketObject}->TicketAccountedTimeGet( TicketID => $TicketID );
+            $Ticket{AccountedTime} = $TicketObject->TicketAccountedTimeGet( TicketID => $TicketID );
         }
 
         $Ticket{SolutionTime}                ||= '';
@@ -1120,13 +1211,13 @@ sub GetStatTable {
 
                     # convert from stored keys to values for certain Dynamic Fields like
                     # Dropdown, Checkbox and Multiselect
-                    my $ValueLookup = $Self->{BackendObject}->ValueLookup(
+                    my $ValueLookup = $DynamicFieldBackendObject->ValueLookup(
                         DynamicFieldConfig => $DynamicFieldConfig,
                         Key                => $Ticket{$ParameterName},
                     );
 
                     # get field value in plain text
-                    my $ValueStrg = $Self->{BackendObject}->ReadableValueRender(
+                    my $ValueStrg = $DynamicFieldBackendObject->ReadableValueRender(
                         DynamicFieldConfig => $DynamicFieldConfig,
                         Value              => $ValueLookup,
                     );
@@ -1178,10 +1269,13 @@ sub GetHeaderLine {
     my $SortedAttributesRef = $Self->_SortedAttributes();
     my @HeaderLine;
 
+    # get language object
+    my $LanguageObject = $Kernel::OM->Get('Kernel::Language');
+
     ATTRIBUTE:
     for my $Attribute ( @{$SortedAttributesRef} ) {
         next ATTRIBUTE if !$SelectedAttributes{$Attribute};
-        push @HeaderLine, $TicketAttributes->{$Attribute};
+        push @HeaderLine, $LanguageObject->Translate( $TicketAttributes->{$Attribute} );
     }
     return \@HeaderLine;
 }
@@ -1189,6 +1283,12 @@ sub GetHeaderLine {
 sub ExportWrapper {
     my ( $Self, %Param ) = @_;
 
+    # get needed objects
+    my $UserObject     = $Kernel::OM->Get('Kernel::System::User');
+    my $QueueObject    = $Kernel::OM->Get('Kernel::System::Queue');
+    my $StateObject    = $Kernel::OM->Get('Kernel::System::State');
+    my $PriorityObject = $Kernel::OM->Get('Kernel::System::Priority');
+
     # wrap ids to used spelling
     for my $Use (qw(UseAsValueSeries UseAsRestriction UseAsXvalue)) {
         ELEMENT:
@@ -1201,11 +1301,11 @@ sub ExportWrapper {
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
-                    $ID->{Content} = $Self->{QueueObject}->QueueLookup( QueueID => $ID->{Content} );
+                    $ID->{Content} = $QueueObject->QueueLookup( QueueID => $ID->{Content} );
                 }
             }
             elsif ( $ElementName eq 'StateIDs' || $ElementName eq 'CreatedStateIDs' ) {
-                my %StateList = $Self->{StateObject}->StateList( UserID => 1 );
+                my %StateList = $StateObject->StateList( UserID => 1 );
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
@@ -1213,7 +1313,7 @@ sub ExportWrapper {
                 }
             }
             elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
-                my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
+                my %PriorityList = $PriorityObject->PriorityList( UserID => 1 );
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
@@ -1229,7 +1329,7 @@ sub ExportWrapper {
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
-                    $ID->{Content} = $Self->{UserObject}->UserLookup( UserID => $ID->{Content} );
+                    $ID->{Content} = $UserObject->UserLookup( UserID => $ID->{Content} );
                 }
             }
 
@@ -1242,6 +1342,12 @@ sub ExportWrapper {
 sub ImportWrapper {
     my ( $Self, %Param ) = @_;
 
+    # get needed objects
+    my $UserObject     = $Kernel::OM->Get('Kernel::System::User');
+    my $QueueObject    = $Kernel::OM->Get('Kernel::System::Queue');
+    my $StateObject    = $Kernel::OM->Get('Kernel::System::State');
+    my $PriorityObject = $Kernel::OM->Get('Kernel::System::Priority');
+
     # wrap used spelling to ids
     for my $Use (qw(UseAsValueSeries UseAsRestriction UseAsXvalue)) {
         ELEMENT:
@@ -1254,12 +1360,11 @@ sub ImportWrapper {
                 ID:
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
-                    if ( $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} ) ) {
-                        $ID->{Content}
-                            = $Self->{QueueObject}->QueueLookup( Queue => $ID->{Content} );
+                    if ( $QueueObject->QueueLookup( Queue => $ID->{Content} ) ) {
+                        $ID->{Content} = $QueueObject->QueueLookup( Queue => $ID->{Content} );
                     }
                     else {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'error',
                             Message  => "Import: Can' find the queue $ID->{Content}!"
                         );
@@ -1272,7 +1377,7 @@ sub ImportWrapper {
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
 
-                    my %State = $Self->{StateObject}->StateGet(
+                    my %State = $StateObject->StateGet(
                         Name  => $ID->{Content},
                         Cache => 1,
                     );
@@ -1280,7 +1385,7 @@ sub ImportWrapper {
                         $ID->{Content} = $State{ID};
                     }
                     else {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'error',
                             Message  => "Import: Can' find state $ID->{Content}!"
                         );
@@ -1289,7 +1394,7 @@ sub ImportWrapper {
                 }
             }
             elsif ( $ElementName eq 'PriorityIDs' || $ElementName eq 'CreatedPriorityIDs' ) {
-                my %PriorityList = $Self->{PriorityObject}->PriorityList( UserID => 1 );
+                my %PriorityList = $PriorityObject->PriorityList( UserID => 1 );
                 my %PriorityIDs;
                 for my $Key ( sort keys %PriorityList ) {
                     $PriorityIDs{ $PriorityList{$Key} } = $Key;
@@ -1302,7 +1407,7 @@ sub ImportWrapper {
                         $ID->{Content} = $PriorityIDs{ $ID->{Content} };
                     }
                     else {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'error',
                             Message  => "Import: Can' find priority $ID->{Content}!"
                         );
@@ -1320,13 +1425,13 @@ sub ImportWrapper {
                 for my $ID ( @{$Values} ) {
                     next ID if !$ID;
 
-                    if ( $Self->{UserObject}->UserLookup( UserLogin => $ID->{Content} ) ) {
-                        $ID->{Content} = $Self->{UserObject}->UserLookup(
+                    if ( $UserObject->UserLookup( UserLogin => $ID->{Content} ) ) {
+                        $ID->{Content} = $UserObject->UserLookup(
                             UserLogin => $ID->{Content}
                         );
                     }
                     else {
-                        $Self->{LogObject}->Log(
+                        $Kernel::OM->Get('Kernel::System::Log')->Log(
                             Priority => 'error',
                             Message  => "Import: Can' find user $ID->{Content}!"
                         );
@@ -1344,9 +1449,12 @@ sub ImportWrapper {
 sub _TicketAttributes {
     my $Self = shift;
 
+    # get config object
+    my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
+
     my %TicketAttributes = (
-        Number => 'Number',    # only a counter for a better readability
-        TicketNumber => $Self->{ConfigObject}->Get('Ticket::Hook'),
+        Number       => 'Number',                             # only a counter for a better readability
+        TicketNumber => $ConfigObject->Get('Ticket::Hook'),
 
         #TicketID       => 'TicketID',
         Age   => 'Age',
@@ -1370,7 +1478,7 @@ sub _TicketAttributes {
 
         #LockID         => 'LockID',
         UnlockTimeout       => 'UnlockTimeout',
-        AccountedTime       => 'Accounted time',       # the same wording is in AgentTicketPrint.dtl
+        AccountedTime       => 'Accounted time',        # the same wording is in AgentTicketPrint.dtl
         RealTillTimeNotUsed => 'RealTillTimeNotUsed',
 
         #GroupID        => 'GroupID',
@@ -1418,7 +1526,7 @@ sub _TicketAttributes {
         SolutionTimeWorkingTime     => 'SolutionTimeWorkingTime',
     );
 
-    if ( $Self->{ConfigObject}->Get('Ticket::Service') ) {
+    if ( $ConfigObject->Get('Ticket::Service') ) {
         $TicketAttributes{Service} = 'Service';
 
         #$TicketAttributes{ServiceID} = 'ServiceID',
@@ -1426,13 +1534,13 @@ sub _TicketAttributes {
         $TicketAttributes{SLAID} = 'SLAID';
     }
 
-    if ( $Self->{ConfigObject}->Get('Ticket::Type') ) {
+    if ( $ConfigObject->Get('Ticket::Type') ) {
         $TicketAttributes{Type} = 'Type';
 
         #$TicketAttributes{TypeID} = 'TypeID';
     }
 
-    if ( $Self->{ConfigObject}->Get('Stats::UseAgentElementInStats') ) {
+    if ( $ConfigObject->Get('Stats::UseAgentElementInStats') ) {
         $TicketAttributes{Owner} = 'Agent/Owner';
 
         #$TicketAttributes{OwnerID}        = 'OwnerID';
@@ -1447,8 +1555,7 @@ sub _TicketAttributes {
         next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
         next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
 
-        $TicketAttributes{ 'DynamicField_' . $DynamicFieldConfig->{Name} }
-            = $DynamicFieldConfig->{Label}
+        $TicketAttributes{ 'DynamicField_' . $DynamicFieldConfig->{Name} } = $DynamicFieldConfig->{Label}
     }
 
     return \%TicketAttributes;
@@ -1582,6 +1689,9 @@ sub _OrderByIsValueOfTicketSearchSort {
         Type                   => 'Type',
     );
 
+    # get dynamic field backend object
+    my $DynamicFieldBackendObject = $Kernel::OM->Get('Kernel::System::DynamicField::Backend');
+
     # cycle trought the Dynamic Fields
     DYNAMICFIELD:
     for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
@@ -1589,7 +1699,7 @@ sub _OrderByIsValueOfTicketSearchSort {
         next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
 
         # get dynamic field sortable condition
-        my $IsSortable = $Self->{BackendObject}->HasBehavior(
+        my $IsSortable = $DynamicFieldBackendObject->HasBehavior(
             DynamicFieldConfig => $DynamicFieldConfig,
             Behavior           => 'IsSortable',
         );
@@ -1678,7 +1788,7 @@ sub _IndividualResultOrder {
         @Sorted = sort { $a->[$Counter] <=> $b->[$Counter] } @Unsorted;
     }
     else {
-        $Self->{LogObject}->Log(
+        $Kernel::OM->Get('Kernel::System::Log')->Log(
             Priority => 'error',
             Message =>
                 "There is no possibility to order the stats by $Param{OrderBy}! Sort it alpha numerical",
