@@ -1,7 +1,6 @@
 #!/usr/bin/perl
 # --
-# bin/otrs.GenericInterfaceDebugRead.pl - the global test handle
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU AFFERO General Public License as published by
@@ -10,12 +9,12 @@
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 # or see http://www.gnu.org/licenses/agpl.txt.
 # --
 
@@ -30,12 +29,7 @@ use lib dirname($RealBin) . '/Custom';
 
 use Getopt::Std;
 
-use Kernel::Config;
-use Kernel::System::Encode;
-use Kernel::System::Time;
-use Kernel::System::Log;
-use Kernel::System::Main;
-use Kernel::System::DB;
+use Kernel::System::ObjectManager;
 use Kernel::System::GenericInterface::DebugLog;
 
 sub PrintHelp {
@@ -52,32 +46,27 @@ Options:
     -i        RemoteIP          => '192.168.0.1',                       # optional, must be valid IPv4 or IPv6 address
     -w        WebserviceID      => 1,                                   # optional
     -d        WithData          => 1,                                   # optional
-Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
+Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 EOF
 }
 
 # get options
-my %Opts = ();
-getopt( 'hctabiwd:', \%Opts );
+my %Opts;
+getopt( 'ctabiwd:', \%Opts );
 if ( $Opts{h} ) {
     PrintHelp();
     exit 1;
 }
 
-# create common objects
-my %CommonObject;
-$CommonObject{ConfigObject} = Kernel::Config->new();
-$CommonObject{EncodeObject} = Kernel::System::Encode->new(%CommonObject);
-$CommonObject{LogObject}    = Kernel::System::Log->new(
-    LogPrefix => 'OTRS-otrs.GenericInterfaceDebugRead.pl',
-    %CommonObject,
+# create object manager
+local $Kernel::OM = Kernel::System::ObjectManager->new(
+    'Kernel::System::Log' => {
+        LogPrefix => 'OTRS-otrs.GenericInterfaceDebugRead.pl',
+    },
 );
-$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
-$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
-$CommonObject{DBObject}   = Kernel::System::DB->new(%CommonObject);
 
 # create needed objects
-my $DebugLogObject = Kernel::System::GenericInterface::DebugLog->new(%CommonObject);
+my $DebugLogObject = Kernel::System::GenericInterface::DebugLog->new();
 print "Searching for DebugLog entries...\n\n";
 
 # LogSearch
@@ -91,7 +80,7 @@ my $LogData = $DebugLogObject->LogSearch(
     WithData          => $Opts{d},
 );
 
-#    print $CommonObject{MainObject}->Dump(\%Opts);
+#    print $Kernel::OM->Get('Kernel::System::Main')->Dump(\%Opts);
 if ( ref $LogData eq 'ARRAY' ) {
     my $Counter = 0;
     for my $Item ( @{$LogData} ) {
