@@ -1,8 +1,5 @@
 // --
-// Core.Agent.Stats.js - provides the special module functions for AgentStats
-// Copyright (C) 2001-2011 OTRS AG, http://otrs.org/
-// --
-// $Id: Core.Agent.Stats.js,v 1.5 2011/10/31 11:22:01 mg Exp $
+// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -56,7 +53,7 @@ Core.Agent.Stats = (function (TargetNS) {
      * @param {Object} The name of the radio button to be selected
      */
     TargetNS.SelectCheckbox = function (Name) {
-        $('input:checkbox[name=' + Name + ']').attr('checked', 'checked');
+        $('input[type="checkbox"][name=' + Name + ']').prop('checked', true);
     };
 
     /**
@@ -68,8 +65,8 @@ Core.Agent.Stats = (function (TargetNS) {
      */
 
     TargetNS.SelectRadiobutton = function (Value, Name) {
-        $('input:radio[name=' + Name + '][value=' + Value + ']').attr('checked', 'checked');
+        $('input[type="radio"][name=' + Name + '][value=' + Value + ']').prop('checked', true);
     };
 
     return TargetNS;
-}(Core.Agent.Stats || {}));
\ No newline at end of file
+}(Core.Agent.Stats || {}));
