@@ -1,8 +1,5 @@
 // --
-// Core.Agent.TicketZoom.js - provides the special module functions for TicketZoom
-// Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-// --
-// $Id: Core.Agent.TicketZoom.js,v 1.37.2.3 2012-10-23 11:55:25 mn Exp $
+// Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -34,7 +31,7 @@ Core.Agent.TicketZoom = (function (TargetNS) {
     TargetNS.MarkTicketAsSeen = function (TicketID) {
         TargetNS.TicketMarkAsSeenTimeout = window.setTimeout(function () {
             // Mark old row as readed
-            $('#FixedTable .ArticleID').closest('tr').removeClass('UnreadArticles').find('span.UnreadArticles').remove();
+            $('#ArticleTable .ArticleID').closest('tr').removeClass('UnreadArticles').find('span.UnreadArticles').remove();
 
             // Mark article as seen in backend
             var Data = {
@@ -57,10 +54,19 @@ Core.Agent.TicketZoom = (function (TargetNS) {
      * @return nothing
      *      Mark an article as seen in frontend and backend.
      */
-    TargetNS.MarkAsSeen = function (TicketID, ArticleID) {
+    TargetNS.MarkAsSeen = function (TicketID, ArticleID, Timeout) {
+
+        // assign default timeout
+        if (typeof Timeout === 'undefined') {
+            Timeout = 3000;
+        }
+
         TargetNS.MarkAsSeenTimeout = window.setTimeout(function () {
             // Mark old row as readed
-            $('#FixedTable .ArticleID[value=' + ArticleID + ']').closest('tr').removeClass('UnreadArticles').find('span.UnreadArticles').remove();
+            $('#ArticleTable .ArticleID[value=' + ArticleID + ']').closest('tr').removeClass('UnreadArticles').find('span.UnreadArticles').remove();
+            $('.ChronicalView li#ArticleID_' + ArticleID).find('.UnreadArticles').fadeOut(function() {
+                $(this).closest('li').addClass('Seen');
+            });
 
             // Mark article as seen in backend
             var Data = {
@@ -74,7 +80,7 @@ Core.Agent.TicketZoom = (function (TargetNS) {
                 Data,
                 function () {}
             );
-        }, 3000);
+        }, parseInt(Timeout, 10));
     };
 
     /**
@@ -107,14 +113,26 @@ Core.Agent.TicketZoom = (function (TargetNS) {
      *      This function loads the given article via ajax
      */
     function LoadArticle(ArticleURL, ArticleID) {
-
         // Clear timeout for URL hash check, because hash is now changed manually
         window.clearTimeout(CheckURLHashTimeout);
 
         // Add loader to the widget
         $('#ArticleItems .WidgetBox').addClass('Loading');
         Core.AJAX.ContentUpdate($('#ArticleItems'), ArticleURL, function () {
-            var TicketScrollerTop = 0;
+            // Top position of Scroller element (surrounds article table)
+            var ScrollerY = parseInt($('div.Scroller').offset().top, 10),
+            // Height of scroller element
+                ScrollerHeight = parseInt($('div.Scroller').height(), 10),
+            // Top position of active article (offset based on screen position)
+                ActiveArticlePosY = parseInt($('#ArticleTable tbody tr.Active').offset().top, 10),
+            // Height of active article
+                ActiveArticleHeight = parseInt($('#ArticleTable tbody tr.Active').height(), 10),
+            // Bottom position of active article
+                ActiveArticleBottomY = ActiveArticlePosY + ActiveArticleHeight,
+            // Bottom position of scroller element
+                ScrollerBottomY = ScrollerY + ScrollerHeight,
+            // Offset of scroller element (relative)
+                ScrollerOffset = $('div.Scroller').get(0).scrollTop;
 
             $('#ArticleItems a.AsPopup').bind('click', function (Event) {
                 var Matches,
@@ -146,8 +164,17 @@ Core.Agent.TicketZoom = (function (TargetNS) {
             $('#ArticleItems .WidgetBox').removeClass('Loading');
 
             // Scroll to new active article
-            TicketScrollerTop = parseInt($('#FixedTable tbody tr.Active').offset().top, 10) - parseInt($('#FixedTable tbody').offset().top, 10);
-            $('div.Scroller').get(0).scrollTop = TicketScrollerTop;
+            // if article is not visible and is above the visible area, move the visible area
+            // add 5px of delta for better usability (top border is definetly visible)
+            if (ActiveArticlePosY < ScrollerY) {
+                $('div.Scroller').get(0).scrollTop = ScrollerOffset + (ActiveArticlePosY - ScrollerY) - 5;
+            }
+            // if article is not visible and is below the visible area, move the visible area
+            // add 5px of delta for better usability (bottom border is definetly visible)
+            else if (ScrollerBottomY < ActiveArticleBottomY) {
+                $('div.Scroller').get(0).scrollTop = ScrollerOffset + (ActiveArticleBottomY - ScrollerBottomY) + 5;
+            }
+
 
             // Initiate URL hash check again
             TargetNS.CheckURLHash();
@@ -159,6 +186,35 @@ Core.Agent.TicketZoom = (function (TargetNS) {
         });
     }
 
+    /**
+     * @function
+     * @return nothing
+     *      Used in OTRSBusiness
+     */
+    TargetNS.LoadArticleFromExternal = function (ArticleID, WindowObject) {
+        var $Element = $('#ArticleTable td.No input.ArticleID[value=' + ArticleID +']'),
+            ArticleURL;
+
+        // Check if we are in timeline view
+        // in this case we can jump directly to the article
+        if ($('.ArticleView .Chronical').hasClass('Active')) {
+            window.location.hash = '#ArticleID_' + ArticleID;
+        }
+        else {
+            if (!$Element.length) {
+                if (typeof WindowObject === 'undefined') {
+                    WindowObject = window;
+                }
+                WindowObject.alert(Core.Config.Get('Language.AttachmentViewMessage'));
+
+                return;
+            }
+
+            ArticleURL = $Element.siblings('.ArticleInfo').val();
+            LoadArticle(ArticleURL, ArticleID);
+        }
+    };
+
     /**
      * @function
      * @return nothing
@@ -185,7 +241,7 @@ Core.Agent.TicketZoom = (function (TargetNS) {
             TargetNS.ActiveURLHash = URLHash;
 
             // if article ID is found in article list (= article id is valid)
-            $ArticleElement = $('#FixedTable').find('input.ArticleID[value=' + TargetNS.ActiveURLHash + ']');
+            $ArticleElement = $('#ArticleTable').find('input.ArticleID[value=' + TargetNS.ActiveURLHash + ']');
             if ($ArticleElement.length) {
                 // Add active state to new row
                 $($ArticleElement).closest('table').find('tr').removeClass('Active').end().end().closest('tr').addClass('Active');
@@ -209,9 +265,7 @@ Core.Agent.TicketZoom = (function (TargetNS) {
      *      This function initializes the special module functions
      */
     TargetNS.Init = function (Options) {
-        var $THead = $('#FixedTable thead'),
-            $TBody = $('#FixedTable tbody'),
-            ZoomExpand = false,
+        var ZoomExpand = false,
             URLHash,
             $ArticleElement,
             ResizeTimeoutScroller,
@@ -230,16 +284,9 @@ Core.Agent.TicketZoom = (function (TargetNS) {
                 Core.Agent.PreferencesUpdate('UserTicketZoomArticleTableHeight', Height);
             }, 1000);
         });
-        Core.UI.InitTableHead($THead, $TBody);
 
-        $(window).bind('resize', function () {
-            window.clearTimeout(ResizeTimeoutWindow);
-            ResizeTimeoutWindow = window.setTimeout(function () {
-                Core.UI.AdjustTableHead($THead, $TBody, 0);
-            }, 500);
-        });
 
-        $('.TableSmall tbody td a.Attachment').bind('click', function (Event) {
+        $('.DataTable tbody td a.Attachment').bind('click', function (Event) {
             var Position, HTML, $HTMLObject;
             if ($(this).attr('rel') && $('#' + $(this).attr('rel')).length) {
                 Position = $(this).offset();
@@ -251,7 +298,7 @@ Core.Agent.TicketZoom = (function (TargetNS) {
         });
 
         // Table sorting
-        Core.UI.Table.Sort.Init($('#FixedTable'), function () {
+        Core.UI.Table.Sort.Init($('#ArticleTable'), function () {
             $(this).find('tr')
                 .removeClass('Even')
                 .filter(':even')
@@ -268,12 +315,12 @@ Core.Agent.TicketZoom = (function (TargetNS) {
 
             // if URL hash is empty, set it initially to the active article for working browser history
             if (URLHash === '') {
-                InitialArticleID = $('#FixedTable tr.Active input.ArticleID').val();
-                //location.hash = '#' + $('#FixedTable tr.Active input.ArticleID').val();
+                InitialArticleID = $('#ArticleTable tr.Active input.ArticleID').val();
+                //location.hash = '#' + $('#ArticleTable tr.Active input.ArticleID').val();
             }
             else {
                 // if article ID is found in article list (= article id is valid)
-                $ArticleElement = $('#FixedTable').find('input.ArticleID[value=' + URLHash + ']');
+                $ArticleElement = $('#ArticleTable').find('input.ArticleID[value=' + URLHash + ']');
                 if ($ArticleElement.length) {
 
                     // Add active state to new row
@@ -284,12 +331,14 @@ Core.Agent.TicketZoom = (function (TargetNS) {
                 }
             }
         }
+        $('a.Chronical').bind('click', function() {
+            $(this).attr('href', $(this).attr('href') + ';ArticleID=' + URLHash);
+        });
 
         // loading new articles
-        $('#FixedTable tbody tr').bind('click', function (Event) {
+        $('#ArticleTable tbody tr').bind('click', function (Event) {
             // Mode: show one article - load new article via ajax
             if (!ZoomExpand) {
-
                 // Add active state to new row
                 $(this).closest('table').find('tr').removeClass('Active').end().end().addClass('Active');
 
@@ -327,8 +376,17 @@ Core.Agent.TicketZoom = (function (TargetNS) {
         });
 
         // Scroll to active article
-        if ( !ZoomExpand && $('#FixedTable tbody tr.Active').length ) {
-            $('div.Scroller').get(0).scrollTop = parseInt($('#FixedTable tbody tr.Active').position().top, 10) - 30;
+        if ( !ZoomExpand && $('#ArticleTable tbody tr.Active').length ) {
+            $('div.Scroller').get(0).scrollTop = parseInt($('#ArticleTable tbody tr.Active').position().top, 10) - 30;
+        }
+
+        // init browser link message close button
+        if ($('.MessageBrowser').length) {
+            $('.MessageBrowser a.Close').on('click', function () {
+                $('.MessageBrowser').fadeOut("slow");
+                Core.Agent.PreferencesUpdate('UserAgentDoNotShowBrowserLinkMessage', 1);
+                return false;
+            });
         }
     };
 
